# MrPeace

<b> MrPeace </b> is a peaceful command line interface for peacing out when time is limited.

It aims to make the process of writing command line tools quick and fun while also preventing any frustration caused by the inability to implement an intended CLI API.

<img width="50%" height="50%" src='https://i.giphy.com/media/jUwpNzg9IcyrK/giphy.webp'/>

# Installation

```bash
pip3 install mrpeace
```

# App Permissions

To allow SMTP to send emails on your behalf start by enabling less secure apps to access your account. For detailed instructions on how to do this, you should check out this <a href ='https://support.google.com/accounts/answer/6010255'>page</a>.

```
twine upload dist/*
```
